==> haskell-cereal-0.5.8.3-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cereal.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 cereal
version:              0.5.8.3
visibility:           public
id:                   cereal-0.5.8.3-KCibhvvTsuv86wVgcPkD6
key:                  cereal-0.5.8.3-KCibhvvTsuv86wVgcPkD6
license:              BSD-3-Clause
maintainer:           Eric Mertens <emertens@galois.com>
author:
    Lennart Kolmodin <kolmodin@dtek.chalmers.se>,
    Galois Inc.,
    Lemmih <lemmih@gmail.com>,
    Bas van Dijk <v.dijk.bas@gmail.com>

stability:            provisional
homepage:             https://github.com/GaloisInc/cereal
synopsis:             A binary serialization library
description:
    A binary serialization library, similar to binary, that introduces an isolate
    primitive for parser isolation, and labeled blocks for better error messages.

category:             Data, Parsing
abi:                  778067bf78a89bb243fcc1e6ee8b3843
exposed:              True
exposed-modules:
    Data.Serialize Data.Serialize.Get Data.Serialize.IEEE754
    Data.Serialize.Put

import-dirs:          /usr/lib/ghc-9.0.2/site-local/cereal-0.5.8.3
library-dirs:         /usr/lib/ghc-9.0.2/site-local/cereal-0.5.8.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-cereal
hs-libraries:         HScereal-0.5.8.3-KCibhvvTsuv86wVgcPkD6
depends:
    array-0.5.4.0 base-4.15.1.0 bytestring-0.10.12.1 containers-0.6.4.1
    ghc-prim-0.7.0

haddock-interfaces:   /usr/share/doc/haskell-cereal/html/cereal.haddock
haddock-html:         /usr/share/doc/haskell-cereal/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cereal-0.5.8.3-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cereal.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 cereal
version:              0.5.8.3
visibility:           public
id:                   cereal-0.5.8.3-9zcITCTkqXtHoa6jbeSF22
key:                  cereal-0.5.8.3-9zcITCTkqXtHoa6jbeSF22
license:              BSD-3-Clause
maintainer:           Eric Mertens <emertens@galois.com>
author:
    Lennart Kolmodin <kolmodin@dtek.chalmers.se>,
    Galois Inc.,
    Lemmih <lemmih@gmail.com>,
    Bas van Dijk <v.dijk.bas@gmail.com>

stability:            provisional
homepage:             https://github.com/GaloisInc/cereal
synopsis:             A binary serialization library
description:
    A binary serialization library, similar to binary, that introduces an isolate
    primitive for parser isolation, and labeled blocks for better error messages.

category:             Data, Parsing
abi:                  c4ff0d9f276ba27b56bdd8936b64e46a
exposed:              True
exposed-modules:
    Data.Serialize Data.Serialize.Get Data.Serialize.IEEE754
    Data.Serialize.Put

import-dirs:          /usr/lib/ghc-9.2.8/site-local/cereal-0.5.8.3
library-dirs:         /usr/lib/ghc-9.2.8/site-local/cereal-0.5.8.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-cereal
hs-libraries:         HScereal-0.5.8.3-9zcITCTkqXtHoa6jbeSF22
depends:
    array-0.5.4.0 base-4.16.4.0 bytestring-0.11.4.0 containers-0.6.5.1
    ghc-prim-0.8.0

haddock-interfaces:   /usr/share/doc/haskell-cereal/html/cereal.haddock
haddock-html:         /usr/share/doc/haskell-cereal/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
